==> qtjambi-qt3dcore-debuginfo-linux-x64-6.5.5.jar: sources/QtJambi3DCore/QAbstractAspect_shell.h <==
#ifndef QABSTRACTASPECT_SHELL_H
#define QABSTRACTASPECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <Qt3DCore/qabstractaspect.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/QBackendNodeMapper>
#include <Qt3DCore/qaspectjob.h>
#include <Qt3DCore/qbackendnode.h>
#include <Qt3DCore/qnodeid.h>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QAbstractAspect_shell : public Qt3DCore::QAbstractAspect, public QtJambiShellInterface
{
public:
    QAbstractAspect_shell(QObject* parent0 = nullptr);
    ~QAbstractAspect_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QStringList dependencies() const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractAspect_access : public Qt3DCore::QAbstractAspect
{
    void __qt_registerBackendType_cref_QMetaObject_cref_QSharedPointer(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject obj0, jobject functor1);
    jobject __qt_rootEntityId_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_unregisterBackendType_cref_QMetaObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject arg__1);
    jobject __qt_dependencies_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QABSTRACTASPECT_SHELL_H

==> qtjambi-qt3dcore-debuginfo-linux-x64-6.6.0.jar: sources/QtJambi3DCore/QAbstractAspect_shell.h <==
#ifndef QABSTRACTASPECT_SHELL_H
#define QABSTRACTASPECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <Qt3DCore/qabstractaspect.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/QBackendNodeMapper>
#include <Qt3DCore/qaspectjob.h>
#include <Qt3DCore/qbackendnode.h>
#include <Qt3DCore/qnodeid.h>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QAbstractAspect_shell : public Qt3DCore::QAbstractAspect, public QtJambiShellInterface
{
public:
    QAbstractAspect_shell(QObject* parent0 = nullptr);
    ~QAbstractAspect_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QStringList dependencies() const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractAspect_access : public Qt3DCore::QAbstractAspect
{
    void __qt_registerBackendType_cref_QMetaObject_cref_QSharedPointer(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject obj0, jobject functor1);
    jobject __qt_rootEntityId(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_unregisterBackendType_cref_QMetaObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject arg__1);
    jobject __qt_dependencies(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QABSTRACTASPECT_SHELL_H
